@@ -54,8 +54,6 @@
 
 #include <private/qschemanumeric_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 /**
@@ -151,6 +149,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
