@@ -55,7 +55,6 @@
 #include <private/qcallsite_p.h>
 #include <private/qwithparam_p.h>
 
-QT_BEGIN_HEADER
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -113,7 +112,6 @@ namespace QPatternist
 }
 
 QT_END_NAMESPACE
-QT_END_HEADER
 
 #endif
 
