@@ -55,8 +55,6 @@
 #include <private/qabstractxmlforwarditerator_p.h>
 #include <private/qdynamiccontext_p.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 namespace QPatternist
@@ -232,6 +230,4 @@ namespace QPatternist
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
