@@ -52,8 +52,6 @@
 
 #include "TestItem.h"
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QDate;
@@ -250,7 +248,5 @@ namespace QPatternistSDK
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
 // vim: et:ts=4:sw=4:sts=4
